Enum sp_finality_grandpa::ConsensusLog [−][src]
pub enum ConsensusLog<N: Codec> {
ScheduledChange(ScheduledChange<N>),
ForcedChange(N, ScheduledChange<N>),
OnDisabled(AuthorityIndex),
Pause(N),
Resume(N),
}Expand description
An consensus log item for GRANDPA.
Variants
ScheduledChange(ScheduledChange<N>)Schedule an authority set change.
The earliest digest of this type in a single block will be respected,
provided that there is no ForcedChange digest. If there is, then the
ForcedChange will take precedence.
No change should be scheduled if one is already and the delay has not passed completely.
This should be a pure function: i.e. as long as the runtime can interpret the digest type it should return the same result regardless of the current state.
Tuple Fields of ScheduledChange
0: ScheduledChange<N>ForcedChange(N, ScheduledChange<N>)Force an authority set change.
Forced changes are applied after a delay of imported blocks, while pending changes are applied after a delay of finalized blocks.
The earliest digest of this type in a single block will be respected, with others ignored.
No change should be scheduled if one is already and the delay has not passed completely.
This should be a pure function: i.e. as long as the runtime can interpret the digest type it should return the same result regardless of the current state.
Tuple Fields of ForcedChange
0: N1: ScheduledChange<N>OnDisabled(AuthorityIndex)Note that the authority with given index is disabled until the next change.
Tuple Fields of OnDisabled
A signal to pause the current authority set after the given delay. After finalizing the block at delay the authorities should stop voting.
A signal to resume the current authority set after the given delay. After authoring the block at delay the authorities should resume voting.
Implementations
Try to cast the log entry as a contained signal.
Try to cast the log entry as a contained forced signal.
Try to cast the log entry as a contained pause signal.
Try to cast the log entry as a contained resume signal.